import React, { Component } from 'react';
import PropTypes from 'prop-types';
import FilterGroup from '../FilterGroup';

class FilterControl extends Component {
  constructor(props) {
    super(props);
    const { filterValue } = this.props;
    this.state = {
      filterValue,
    };
    this.onFilterValueChanged = this.onFilterValueChanged.bind(this);
  }

  onFilterValueChanged(filterValue) {
    const { onFilterValueChanged } = this.props;
    this.setState({ filterValue });
    onFilterValueChanged(filterValue);
  }

  render() {
    const { fields, groups } = this.props;
    const { filterValue } = this.state;
    return (
      <div className="fc">
        <FilterGroup
          fields={fields}
          groups={groups}
          filterValue={filterValue}
          onFilterValueChanged={this.onFilterValueChanged}
        />
      </div>
    );
  }
}

FilterControl.propTypes = {
  fields: PropTypes.arrayOf(PropTypes.any).isRequired,
  groups: PropTypes.arrayOf(
    PropTypes.shape({
      name: PropTypes.string,
      caption: PropTypes.string,
    }),
  ),
  filterValue: PropTypes.shape({
    groupName: PropTypes.string,
    items: PropTypes.arrayOf(
      PropTypes.any,
    ),
  }),
  onFilterValueChanged: PropTypes.func.isRequired,
};

FilterControl.defaultProps = {
  groups: [{
    name: 'and',
    caption: 'And',
  }, {
    name: 'or',
    caption: 'Or',
  }],
  filterValue: {
    groupName: 'and',
    items: [],
  },
};

export default FilterControl;
